@@ -1,12 +1,12 @@
 ;;; mic.el --- Minimal and combinable configuration manager  -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2022  ROCKTAKEY
+;; Copyright (C) 2022-2023  ROCKTAKEY
 
 ;; Author: ROCKTAKEY <rocktakey@gmail.com>
 ;; Keywords: convenience
 
-;; Package-Version: 0.36.0
-;; Package-Revision: v0.36.0-0-gfcb51a817135
+;; Package-Version: 20240806.1655
+;; Package-Revision: f552ddf397e8
 ;; Package-Requires: ((emacs "26.1"))
 ;; URL: https://github.com/ROCKTAKEY/mic
 
@@ -1287,8 +1287,10 @@
 
 ;;     ,----
 ;;     | (mic-defmic mic-with-mode-hydra mic
-;;     |   :filters '(mic-filter-mode-hydra))
+;;     |   :filters '(mic-filter-mode-hydra
+;;     |              mic-filter-mode-hydra+))
 ;;     |
+;;     | ;;; `:mode-hydra'
 ;;     | (mic-with-mode-hydra package-name
 ;;     |   :mode-hydra
 ;;     |   (( c-mode (:title "C Mode" :quit-key "q")
@@ -1318,6 +1320,36 @@
 ;;     |        ("<up>" enlarge-window "enlarge-window")
 ;;     |        ("<right>" enlarge-window-horizontally "enlarge-window-horizontally")
 ;;     |        ("<left>" shrink-window-horizontally "shrink-window-horizontally"))))))
+;;     |
+;;     | ;;;  `:mode-hydra+'
+;;     | (mic-with-mode-hydra package-name
+;;     |   :mode-hydra+
+;;     |   (( c-mode (:title "C Mode" :quit-key "q")
+;;     |      ("Alphabet"
+;;     |       (("p" shrink-window "shrink")
+;;     |        ("n" enlarge-window "enlarge")
+;;     |        ("f" enlarge-window-horizontally "enlarge-horizontally")
+;;     |        ("b" shrink-window-horizontally "shrink-horizontally"))
+;;     |       "Arrow"
+;;     |       (("<down>" shrink-window)
+;;     |        ("<up>" enlarge-window)
+;;     |        ("<right>" enlarge-window-horizontally)
+;;     |        ("<left>" shrink-window-horizontally))))))
+;;     |
+;;     | ;; Expanded to:
+;;     | (mic package-name :eval
+;;     |   ((major-mode-hydra-define+ c-mode
+;;     |      (:title "C Mode" :quit-key "q" :hint nil :color teal :separator "═")
+;;     |      ("Alphabet"
+;;     |       (("p" shrink-window "shrink")
+;;     |        ("n" enlarge-window "enlarge")
+;;     |        ("f" enlarge-window-horizontally "enlarge-horizontally")
+;;     |        ("b" shrink-window-horizontally "shrink-horizontally"))
+;;     |       "Arrow"
+;;     |       (("<down>" shrink-window "shrink-window")
+;;     |        ("<up>" enlarge-window "enlarge-window")
+;;     |        ("<right>" enlarge-window-horizontally "enlarge-window-horizontally")
+;;     |        ("<left>" shrink-window-horizontally "shrink-window-horizontally"))))))
 ;;     `----
 
 
@@ -1329,10 +1361,21 @@
 
 ;;   + 5.1.2.3.1 Hook
 
-;;     - `mic-filter-hook-quote'
-;;     This is almost same as `mic-filter-hook', but `cdr' of each element
-;;     of the value should not be quoted.  `:hook-quote' is used as
-;;     keyword.
+;;     `mic-filter-hook-list'
+;;           This is almost same as `mic-filter-hook', but `car' of each
+;;           element of the value should be list of hook, and the `cdr'
+;;           should be list of function (should be quoted).  `:hook-list'
+;;           is used as keyword.
+;;     `mic-filter-hook-list-maybe'
+;;           This is almost same as `mic-filter-hook', but `car' of each
+;;           element of the value should be list of hook or just one hook,
+;;           and the `cdr' should be list of function or just one function
+;;           (should *NOT* be quoted).  `:hook-list-maybe' is used as
+;;           keyword.
+;;     `mic-filter-hook-quote'
+;;           This is almost same as `mic-filter-hook', but `cdr' of each
+;;           element of the value should not be quoted.  `:hook-quote' is
+;;           used as keyword.
 
 
 ;; 5.1.3 Helper for defining a filter
@@ -1586,7 +1629,53 @@
 ;;   `----
 
 
-;; * 5.1.4.2 Adopt a parent other than `mic', `mic-core' and its derivation
+;; * 5.1.4.2 Accept non-plist input
+
+;;   Like `use-package' and `leaf', you can define `mic' which accepts
+;;   non-plist input.  If you want to do so, you should pass `:inputter'
+;;   argument to `mic-defmic'.  `INPUTTER' is a function which takes one
+;;   argument `INPUT', and transform it into `PLIST' as returned value.
+
+;;   Simply, you can use `mic-definputter-pseudo-plist' defined in
+;;   <file:mic-definputter.el> to define inputter like `use-package' or
+;;   `leaf'.  it takes two arguments `NAME' and `LISTIZED-KEYWORDS'.  `NAME'
+;;   is a name of the inputter function, and `LISTIZED-KEYWORDS' is list of
+;;   keyword whose value can be passed multiple times.
+;;   ,----
+;;   | (mic-definputter-pseudo-plist my-inputter
+;;   |   '(:eval :eval-after-load :define-key))
+;;   |
+;;   | (mic-defmic mymic-with-inputter mic
+;;   |   :inputter #'my-inputter)
+;;   |
+;;   | (mymic-with-inputter feature-name
+;;   |   :eval
+;;   |   ;; Like `use-package', you can put multiple sexps after :eval, instead of list of sexp
+;;   |   (message "Hello")
+;;   |   (message "Good bye")
+;;   |
+;;   |   :eval-after-load
+;;   |   (message "Hello, after load")
+;;   |   (message "Good bye, after load")
+;;   |
+;;   |   ;; Instead, list of sexp is not allowed
+;;   |   ;; :eval-after-load
+;;   |   ;; ((message "Hello, after load")
+;;   |   ;;  (message "Good bye, after load"))
+;;   |
+;;   |   :define-key
+;;   |   (global-map
+;;   |    ("M-a" . #'beginning-of-defun))
+;;   |   (esc-map
+;;   |    ("e" . #'end-of-defun))
+;;   |
+;;   |   ;; Other keyword is not affected by inputter
+;;   |   :package
+;;   |   (ivy hydra))
+;;   `----
+
+
+;; * 5.1.4.3 Adopt a parent other than `mic', `mic-core' and its derivation
 
 ;;   You can use other configuration managers, such as [use-package] and
 ;;   [leaf.el].  However, filters defined by `mic' output keyword for `mic'
@@ -1758,7 +1847,9 @@ Information:
 For more information, see `mic-defmic'."
                     (mapconcat
                      (lambda (arg)
-                       (concat "  - `" (pp-to-string arg) "'"))
+                       (concat "  - `"
+                               (if (symbolp arg) (symbol-name arg) (pp-to-string arg))
+                               "'"))
                      filters
                      "\n")
                     parent
